@@ -32,15 +32,9 @@ YELLOW = (255,255,0)
 NUM_ROUNDS = 10
 OFF_SCREEN_LIMIT = 10
 
-game_folder = os.path.dirname(__file__)
-img_folder = os.path.join(game_folder, "img")
-background_file = os.path.join(img_folder, "starfield.png")
-player_file = os.path.join(img_folder, "playerShip1_orange.png")
-enemy_file = os.path.join(img_folder, "meteorBrown_med1.png")
-
 #create a player sprite
 class Player(pygame.sprite.Sprite):
-    def __init__(self):
+    def __init__(self, player_file):
         # create a plain rectangle for the sprite image
         pygame.sprite.Sprite.__init__(self)
         self.image = pygame.Surface((1, 1))
@@ -62,12 +56,12 @@ class Player(pygame.sprite.Sprite):
 
 #create a player sprite
 class Enemy(pygame.sprite.Sprite):
-    def __init__(self):
+    def __init__(self, meteorite_file):
         # create a plain rectangle for the sprite image
         pygame.sprite.Sprite.__init__(self)
         self.image = pygame.Surface((1, 1))
         self.image.fill(RED)
-        self.img = pygame.image.load(enemy_file)
+        self.img = pygame.image.load(meteorite_file)
         self.img = pygame.transform.scale(self.img, (50, 50))
         self.rect = self.image.get_rect()
         self.imgrect = self.img.get_rect()
@@ -83,21 +77,23 @@ class Enemy(pygame.sprite.Sprite):
             self.round+=1
 
 class env:
-    def __init__(self):
+    def __init__(self, background_file, player_file, meteorite_file):
         #Set up screen
         self.screen = pygame.display.set_mode((SCREEN_WIDTH, SCREEN_HEIGHT))
         self.background = pygame.image.load(background_file)
+        self.player_file = player_file
+        self.meteorite_file = meteorite_file
         
         #setup player
         self.all_sprites = pygame.sprite.Group()
         self.img = pygame.sprite.Group()
-        self.player = Player()
+        self.player = Player(player_file)
         self.num_enemies = NUM_ENEMIES
         
         #setup meteroids
         self.enemy_sprites = pygame.sprite.Group()
         for i in range(NUM_ENEMIES):
-            self.enemy = Enemy()
+            self.enemy = Enemy(meteorite_file)
             self.enemy_sprites.add(self.enemy)
             self.all_sprites.add(self.enemy)
     
@@ -144,12 +140,12 @@ class env:
     def reset(self):
         #setup player
         self.all_sprites = pygame.sprite.Group()
-        self.player = Player()
+        self.player = Player(self.player_file)
         
         #setup meteroids
         self.enemy_sprites = pygame.sprite.Group()
         for i in range(NUM_ENEMIES):
-            self.enemy = Enemy()
+            self.enemy = Enemy(self.meteorite_file)
             self.enemy_sprites.add(self.enemy)
             self.all_sprites.add(self.enemy)
     
